@@ -2133,7 +2133,7 @@ comp_editor_init (CompEditor *editor)
 
 	container = GTK_WIDGET (editor);
 
-	widget = gtk_vbox_new (FALSE, 0);
+	widget = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add (GTK_CONTAINER (container), widget);
 	gtk_widget_show (widget);
 
