@@ -32,11 +32,6 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
-#include <misc/e-dateedit.h>
-#include <e-util/e-plugin-ui.h>
-#include <e-util/e-util-private.h>
-#include <e-util/e-ui-manager.h>
-
 #include "event-page.h"
 #include "recurrence-page.h"
 #include "schedule-page.h"
