@@ -22,8 +22,9 @@
  * @short_description: Shared #EClient instances
  *
  * #EClientCache provides for application-wide sharing of #EClient
- * instances and centralized rebroadcasting of #EClient::backend-died
- * and #EClient::backend-error signals from cached #EClient instances.
+ * instances and centralized rebroadcasting of #EClient::backend-died,
+ * #EClient::backend-error and #GObject::notify signals from cached
+ * #EClient instances.
  *
  * #EClientCache automatically invalidates cache entries in response to
  * #EClient::backend-died signals.  The #EClient instance is discarded,
@@ -59,16 +60,19 @@ struct _EClientCachePrivate {
 struct _ClientData {
 	volatile gint ref_count;
 	GMutex lock;
-	GWeakRef cache;
+	GWeakRef client_cache;
 	EClient *client;
 	GQueue connecting;
-	gulong client_died_handler_id;
-	gulong client_error_handler_id;
+	gboolean dead_backend;
+	gulong backend_died_handler_id;
+	gulong backend_error_handler_id;
+	gulong notify_handler_id;
 };
 
 struct _SignalClosure {
-	EClientCache *cache;
+	EClientCache *client_cache;
 	EClient *client;
+	GParamSpec *pspec;
 	gchar *error_message;
 };
 
@@ -88,20 +92,21 @@ enum {
 	BACKEND_DIED,
 	BACKEND_ERROR,
 	CLIENT_CREATED,
+	CLIENT_NOTIFY,
 	LAST_SIGNAL
 };
 
 static guint signals[LAST_SIGNAL];
 
 static ClientData *
-client_data_new (EClientCache *cache)
+client_data_new (EClientCache *client_cache)
 {
 	ClientData *client_data;
 
 	client_data = g_slice_new0 (ClientData);
 	client_data->ref_count = 1;
 	g_mutex_init (&client_data->lock);
-	g_weak_ref_set (&client_data->cache, cache);
+	g_weak_ref_set (&client_data->client_cache, client_cache);
 
 	return client_data;
 }
@@ -128,12 +133,13 @@ client_data_unref (ClientData *client_data)
 		/* The signal handlers hold a reference on client_data,
 		 * so we should not be here unless the signal handlers
 		 * have already been disconnected. */
-		g_warn_if_fail (client_data->client_died_handler_id == 0);
-		g_warn_if_fail (client_data->client_error_handler_id == 0);
+		g_warn_if_fail (client_data->backend_died_handler_id == 0);
+		g_warn_if_fail (client_data->backend_error_handler_id == 0);
+		g_warn_if_fail (client_data->notify_handler_id == 0);
 
 		g_mutex_clear (&client_data->lock);
 		g_clear_object (&client_data->client);
-		g_weak_ref_set (&client_data->cache, NULL);
+		g_weak_ref_set (&client_data->client_cache, NULL);
 
 		/* There should be no connect() operations in progress. */
 		g_warn_if_fail (g_queue_is_empty (&client_data->connecting));
@@ -150,13 +156,18 @@ client_data_dispose (ClientData *client_data)
 	if (client_data->client != NULL) {
 		g_signal_handler_disconnect (
 			client_data->client,
-			client_data->client_died_handler_id);
-		client_data->client_died_handler_id = 0;
+			client_data->backend_died_handler_id);
+		client_data->backend_died_handler_id = 0;
 
 		g_signal_handler_disconnect (
 			client_data->client,
-			client_data->client_error_handler_id);
-		client_data->client_error_handler_id = 0;
+			client_data->backend_error_handler_id);
+		client_data->backend_error_handler_id = 0;
+
+		g_signal_handler_disconnect (
+			client_data->client,
+			client_data->notify_handler_id);
+		client_data->notify_handler_id = 0;
 
 		g_clear_object (&client_data->client);
 	}
@@ -169,16 +180,19 @@ client_data_dispose (ClientData *client_data)
 static void
 signal_closure_free (SignalClosure *signal_closure)
 {
-	g_clear_object (&signal_closure->cache);
+	g_clear_object (&signal_closure->client_cache);
 	g_clear_object (&signal_closure->client);
 
+	if (signal_closure->pspec != NULL)
+		g_param_spec_unref (signal_closure->pspec);
+
 	g_free (signal_closure->error_message);
 
 	g_slice_free (SignalClosure, signal_closure);
 }
 
 static ClientData *
-client_ht_lookup (EClientCache *cache,
+client_ht_lookup (EClientCache *client_cache,
                   ESource *source,
                   const gchar *extension_name)
 {
@@ -189,9 +203,9 @@ client_ht_lookup (EClientCache *cache,
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
 	g_return_val_if_fail (extension_name != NULL, NULL);
 
-	client_ht = cache->priv->client_ht;
+	client_ht = client_cache->priv->client_ht;
 
-	g_mutex_lock (&cache->priv->client_ht_lock);
+	g_mutex_lock (&client_cache->priv->client_ht_lock);
 
 	/* We pre-load the hash table with supported extension names,
 	 * so lookup failures indicate an unsupported extension name. */
@@ -200,96 +214,76 @@ client_ht_lookup (EClientCache *cache,
 		client_data = g_hash_table_lookup (inner_ht, source);
 		if (client_data == NULL) {
 			g_object_ref (source);
-			client_data = client_data_new (cache);
+			client_data = client_data_new (client_cache);
 			g_hash_table_insert (inner_ht, source, client_data);
 		}
 		client_data_ref (client_data);
 	}
 
-	g_mutex_unlock (&cache->priv->client_ht_lock);
+	g_mutex_unlock (&client_cache->priv->client_ht_lock);
 
 	return client_data;
 }
 
-static gchar *
-client_cache_build_source_description (EClientCache *cache,
-                                       ESource *source)
-{
-	ESourceRegistry *registry;
-	ESource *parent;
-	GString *description;
-	gchar *display_name;
-	gchar *parent_uid;
-
-	description = g_string_sized_new (128);
-
-	registry = e_client_cache_ref_registry (cache);
-
-	parent_uid = e_source_dup_parent (source);
-	parent = e_source_registry_ref_source (registry, parent_uid);
-	g_free (parent_uid);
-
-	if (parent != NULL) {
-		display_name = e_source_dup_display_name (parent);
-		g_string_append (description, display_name);
-		g_string_append (description, " / ");
-		g_free (display_name);
-
-		g_object_unref (parent);
-	}
-
-	display_name = e_source_dup_display_name (source);
-	g_string_append (description, display_name);
-	g_free (display_name);
-
-	g_object_unref (registry);
-
-	return g_string_free (description, FALSE);
-}
-
 static gboolean
 client_cache_emit_backend_died_idle_cb (gpointer user_data)
 {
 	SignalClosure *signal_closure = user_data;
+	ESourceRegistry *registry;
 	EAlert *alert;
 	ESource *source;
 	const gchar *alert_id = NULL;
 	const gchar *extension_name;
-	gchar *description;
+	gchar *display_name = NULL;
 
 	source = e_client_get_source (signal_closure->client);
+	registry = e_client_cache_ref_registry (signal_closure->client_cache);
 
 	extension_name = E_SOURCE_EXTENSION_ADDRESS_BOOK;
-	if (e_source_has_extension (source, extension_name))
+	if (e_source_has_extension (source, extension_name)) {
 		alert_id = "system:address-book-backend-died";
+		display_name = e_source_registry_dup_unique_display_name (
+			registry, source, extension_name);
+	}
 
 	extension_name = E_SOURCE_EXTENSION_CALENDAR;
-	if (e_source_has_extension (source, extension_name))
+	if (e_source_has_extension (source, extension_name)) {
 		alert_id = "system:calendar-backend-died";
+		display_name = e_source_registry_dup_unique_display_name (
+			registry, source, extension_name);
+	}
 
 	extension_name = E_SOURCE_EXTENSION_MEMO_LIST;
-	if (e_source_has_extension (source, extension_name))
+	if (e_source_has_extension (source, extension_name)) {
 		alert_id = "system:memo-list-backend-died";
+		display_name = e_source_registry_dup_unique_display_name (
+			registry, source, extension_name);
+	}
 
 	extension_name = E_SOURCE_EXTENSION_TASK_LIST;
-	if (e_source_has_extension (source, extension_name))
+	if (e_source_has_extension (source, extension_name)) {
 		alert_id = "system:task-list-backend-died";
+		display_name = e_source_registry_dup_unique_display_name (
+			registry, source, extension_name);
+	}
+
+	g_object_unref (registry);
 
 	g_return_val_if_fail (alert_id != NULL, FALSE);
+	g_return_val_if_fail (display_name != NULL, FALSE);
 
-	description = client_cache_build_source_description (
-		signal_closure->cache, source);
-	alert = e_alert_new (alert_id, description, NULL);
-	g_free (description);
+	alert = e_alert_new (alert_id, display_name, NULL);
 
 	g_signal_emit (
-		signal_closure->cache,
+		signal_closure->client_cache,
 		signals[BACKEND_DIED], 0,
 		signal_closure->client,
 		alert);
 
 	g_object_unref (alert);
 
+	g_free (display_name);
+
 	return FALSE;
 }
 
@@ -297,47 +291,94 @@ static gboolean
 client_cache_emit_backend_error_idle_cb (gpointer user_data)
 {
 	SignalClosure *signal_closure = user_data;
+	ESourceRegistry *registry;
 	EAlert *alert;
 	ESource *source;
 	const gchar *alert_id = NULL;
 	const gchar *extension_name;
-	gchar *description;
+	gchar *display_name = NULL;
 
 	source = e_client_get_source (signal_closure->client);
+	registry = e_client_cache_ref_registry (signal_closure->client_cache);
 
 	extension_name = E_SOURCE_EXTENSION_ADDRESS_BOOK;
-	if (e_source_has_extension (source, extension_name))
+	if (e_source_has_extension (source, extension_name)) {
 		alert_id = "system:address-book-backend-error";
+		display_name = e_source_registry_dup_unique_display_name (
+			registry, source, extension_name);
+	}
 
 	extension_name = E_SOURCE_EXTENSION_CALENDAR;
-	if (e_source_has_extension (source, extension_name))
+	if (e_source_has_extension (source, extension_name)) {
 		alert_id = "system:calendar-backend-error";
+		display_name = e_source_registry_dup_unique_display_name (
+			registry, source, extension_name);
+	}
 
 	extension_name = E_SOURCE_EXTENSION_MEMO_LIST;
-	if (e_source_has_extension (source, extension_name))
+	if (e_source_has_extension (source, extension_name)) {
 		alert_id = "system:memo-list-backend-error";
+		display_name = e_source_registry_dup_unique_display_name (
+			registry, source, extension_name);
+	}
 
 	extension_name = E_SOURCE_EXTENSION_TASK_LIST;
-	if (e_source_has_extension (source, extension_name))
+	if (e_source_has_extension (source, extension_name)) {
 		alert_id = "system:task-list-backend-error";
+		display_name = e_source_registry_dup_unique_display_name (
+			registry, source, extension_name);
+	}
+
+	g_object_unref (registry);
 
 	g_return_val_if_fail (alert_id != NULL, FALSE);
+	g_return_val_if_fail (display_name != NULL, FALSE);
 
-	description = client_cache_build_source_description (
-		signal_closure->cache, source);
 	alert = e_alert_new (
-		alert_id, description,
+		alert_id, display_name,
 		signal_closure->error_message, NULL);
-	g_free (description);
 
 	g_signal_emit (
-		signal_closure->cache,
+		signal_closure->client_cache,
 		signals[BACKEND_ERROR], 0,
 		signal_closure->client,
 		alert);
 
 	g_object_unref (alert);
 
+	g_free (display_name);
+
+	return FALSE;
+}
+
+static gboolean
+client_cache_emit_client_notify_idle_cb (gpointer user_data)
+{
+	SignalClosure *signal_closure = user_data;
+	const gchar *name;
+
+	name = g_param_spec_get_name (signal_closure->pspec);
+
+	g_signal_emit (
+		signal_closure->client_cache,
+		signals[CLIENT_NOTIFY],
+		g_quark_from_string (name),
+		signal_closure->client,
+		signal_closure->pspec);
+
+	return FALSE;
+}
+
+static gboolean
+client_cache_emit_client_created_idle_cb (gpointer user_data)
+{
+	SignalClosure *signal_closure = user_data;
+
+	g_signal_emit (
+		signal_closure->client_cache,
+		signals[CLIENT_CREATED], 0,
+		signal_closure->client);
+
 	return FALSE;
 }
 
@@ -345,16 +386,16 @@ static void
 client_cache_backend_died_cb (EClient *client,
                               ClientData *client_data)
 {
-	EClientCache *cache;
+	EClientCache *client_cache;
 
-	cache = g_weak_ref_get (&client_data->cache);
+	client_cache = g_weak_ref_get (&client_data->client_cache);
 
-	if (cache != NULL) {
+	if (client_cache != NULL) {
 		GSource *idle_source;
 		SignalClosure *signal_closure;
 
 		signal_closure = g_slice_new0 (SignalClosure);
-		signal_closure->cache = g_object_ref (cache);
+		signal_closure->client_cache = g_object_ref (client_cache);
 		signal_closure->client = g_object_ref (client);
 
 		idle_source = g_idle_source_new ();
@@ -363,11 +404,20 @@ client_cache_backend_died_cb (EClient *client,
 			client_cache_emit_backend_died_idle_cb,
 			signal_closure,
 			(GDestroyNotify) signal_closure_free);
-		g_source_attach (idle_source, cache->priv->main_context);
+		g_source_attach (
+			idle_source, client_cache->priv->main_context);
 		g_source_unref (idle_source);
 
-		g_object_unref (cache);
+		g_object_unref (client_cache);
 	}
+
+	/* Discard the EClient and tag the backend as
+	 * dead until we create a replacement EClient. */
+	g_mutex_lock (&client_data->lock);
+	g_clear_object (&client_data->client);
+	client_data->dead_backend = TRUE;
+	g_mutex_unlock (&client_data->lock);
+
 }
 
 static void
@@ -375,16 +425,16 @@ client_cache_backend_error_cb (EClient *client,
                                const gchar *error_message,
                                ClientData *client_data)
 {
-	EClientCache *cache;
+	EClientCache *client_cache;
 
-	cache = g_weak_ref_get (&client_data->cache);
+	client_cache = g_weak_ref_get (&client_data->client_cache);
 
-	if (cache != NULL) {
+	if (client_cache != NULL) {
 		GSource *idle_source;
 		SignalClosure *signal_closure;
 
 		signal_closure = g_slice_new0 (SignalClosure);
-		signal_closure->cache = g_object_ref (cache);
+		signal_closure->client_cache = g_object_ref (client_cache);
 		signal_closure->client = g_object_ref (client);
 		signal_closure->error_message = g_strdup (error_message);
 
@@ -394,10 +444,43 @@ client_cache_backend_error_cb (EClient *client,
 			client_cache_emit_backend_error_idle_cb,
 			signal_closure,
 			(GDestroyNotify) signal_closure_free);
-		g_source_attach (idle_source, cache->priv->main_context);
+		g_source_attach (
+			idle_source, client_cache->priv->main_context);
 		g_source_unref (idle_source);
 
-		g_object_unref (cache);
+		g_object_unref (client_cache);
+	}
+}
+
+static void
+client_cache_notify_cb (EClient *client,
+                        GParamSpec *pspec,
+                        ClientData *client_data)
+{
+	EClientCache *client_cache;
+
+	client_cache = g_weak_ref_get (&client_data->client_cache);
+
+	if (client_cache != NULL) {
+		GSource *idle_source;
+		SignalClosure *signal_closure;
+
+		signal_closure = g_slice_new0 (SignalClosure);
+		signal_closure->client_cache = g_object_ref (client_cache);
+		signal_closure->client = g_object_ref (client);
+		signal_closure->pspec = g_param_spec_ref (pspec);
+
+		idle_source = g_idle_source_new ();
+		g_source_set_callback (
+			idle_source,
+			client_cache_emit_client_notify_idle_cb,
+			signal_closure,
+			(GDestroyNotify) signal_closure_free);
+		g_source_attach (
+			idle_source, client_cache->priv->main_context);
+		g_source_unref (idle_source);
+
+		g_object_unref (client_cache);
 	}
 }
 
@@ -419,15 +502,21 @@ client_cache_process_results (ClientData *client_data,
 	e_queue_transfer (&client_data->connecting, &queue);
 
 	if (client != NULL) {
-		EClientCache *cache;
+		EClientCache *client_cache;
+
+		/* Make sure we're not leaking a reference. */
+		g_warn_if_fail (client_data->client == NULL);
 
 		client_data->client = g_object_ref (client);
+		client_data->dead_backend = FALSE;
 
-		cache = g_weak_ref_get (&client_data->cache);
+		client_cache = g_weak_ref_get (&client_data->client_cache);
 
 		/* If the EClientCache has been disposed already,
 		 * there's no point in connecting signal handlers. */
-		if (cache != NULL) {
+		if (client_cache != NULL) {
+			GSource *idle_source;
+			SignalClosure *signal_closure;
 			gulong handler_id;
 
 			/* client_data_dispose() will break the
@@ -439,7 +528,7 @@ client_cache_process_results (ClientData *client_data,
 				client_data_ref (client_data),
 				(GClosureNotify) client_data_unref,
 				0);
-			client_data->client_died_handler_id = handler_id;
+			client_data->backend_died_handler_id = handler_id;
 
 			handler_id = g_signal_connect_data (
 				client, "backend-error",
@@ -447,12 +536,32 @@ client_cache_process_results (ClientData *client_data,
 				client_data_ref (client_data),
 				(GClosureNotify) client_data_unref,
 				0);
-			client_data->client_error_handler_id = handler_id;
+			client_data->backend_error_handler_id = handler_id;
 
-			g_signal_emit (
-				cache, signals[CLIENT_CREATED], 0, client);
+			handler_id = g_signal_connect_data (
+				client, "notify",
+				G_CALLBACK (client_cache_notify_cb),
+				client_data_ref (client_data),
+				(GClosureNotify) client_data_unref,
+				0);
+			client_data->notify_handler_id = handler_id;
 
-			g_object_unref (cache);
+			signal_closure = g_slice_new0 (SignalClosure);
+			signal_closure->client_cache =
+				g_object_ref (client_cache);
+			signal_closure->client = g_object_ref (client);
+
+			idle_source = g_idle_source_new ();
+			g_source_set_callback (
+				idle_source,
+				client_cache_emit_client_created_idle_cb,
+				signal_closure,
+				(GDestroyNotify) signal_closure_free);
+			g_source_attach (
+				idle_source, client_cache->priv->main_context);
+			g_source_unref (idle_source);
+
+			g_object_unref (client_cache);
 		}
 	}
 
@@ -518,13 +627,13 @@ client_cache_cal_connect_cb (GObject *source_object,
 }
 
 static void
-client_cache_set_registry (EClientCache *cache,
+client_cache_set_registry (EClientCache *client_cache,
                            ESourceRegistry *registry)
 {
 	g_return_if_fail (E_IS_SOURCE_REGISTRY (registry));
-	g_return_if_fail (cache->priv->registry == NULL);
+	g_return_if_fail (client_cache->priv->registry == NULL);
 
-	cache->priv->registry = g_object_ref (registry);
+	client_cache->priv->registry = g_object_ref (registry);
 }
 
 static void
@@ -638,16 +747,16 @@ e_client_cache_class_init (EClientCacheClass *class)
 
 	/**
 	 * EClientCache::backend-died:
-	 * @cache: the #EClientCache that received the signal
+	 * @client_cache: the #EClientCache that received the signal
 	 * @client: the #EClient that received the D-Bus notification
 	 * @alert: an #EAlert with a user-friendly error description
 	 *
 	 * Rebroadcasts a #EClient::backend-died signal emitted by @client,
 	 * along with a pre-formatted #EAlert.
 	 *
-	 * As a convenience to signal handlers, this signal is always emitted
-	 * from the #GMainContext that was thread-default when the @cache was
-	 * created.
+	 * As a convenience to signal handlers, this signal is always
+	 * emitted from the #GMainContext that was thread-default when
+	 * the @client_cache was created.
 	 **/
 	signals[BACKEND_DIED] = g_signal_new (
 		"backend-died",
@@ -661,16 +770,16 @@ e_client_cache_class_init (EClientCacheClass *class)
 
 	/**
 	 * EClientCache::backend-error:
-	 * @cache: the #EClientCache that received the signal
+	 * @client_cache: the #EClientCache that received the signal
 	 * @client: the #EClient that received the D-Bus notification
 	 * @alert: an #EAlert with a user-friendly error description
 	 *
 	 * Rebroadcasts a #EClient::backend-error signal emitted by @client,
 	 * along with a pre-formatted #EAlert.
 	 *
-	 * As a convenience to signal handlers, this signal is always emitted
-	 * from the #GMainContext that was thread-default when the @cache was
-	 * created.
+	 * As a convenience to signal handlers, this signal is always
+	 * emitted from the #GMainContext that was thread-default when
+	 * the @client_cache was created.
 	 **/
 	signals[BACKEND_ERROR] = g_signal_new (
 		"backend-error",
@@ -684,7 +793,7 @@ e_client_cache_class_init (EClientCacheClass *class)
 
 	/**
 	 * EClientCache::client-created:
-	 * @cache: the #EClientCache the received the signal
+	 * @client_cache: the #EClientCache that received the signal
 	 * @client: the newly-created #EClient
 	 *
 	 * This signal is emitted when a call to e_client_cache_get_client()
@@ -698,10 +807,41 @@ e_client_cache_class_init (EClientCacheClass *class)
 		NULL, NULL, NULL,
 		G_TYPE_NONE, 1,
 		E_TYPE_CLIENT);
+
+	/**
+	 * EClientCache::client-notify:
+	 * @client_cache: the #EClientCache that received the signal
+	 * @client: the #EClient whose property changed
+	 * @pspec: the #GParamSpec of the property that changed
+	 *
+	 * Rebroadcasts a #GObject::notify signal emitted by @client.
+	 *
+	 * This signal supports "::detail" appendices to the signal name
+	 * just like the #GObject::notify signal, so you can connect to
+	 * change notification signals for specific #EClient properties.
+	 *
+	 * As a convenience to signal handlers, this signal is always
+	 * emitted from the #GMainContext that was thread-default when
+	 * the @client_cache was created.
+	 **/
+	signals[CLIENT_NOTIFY] = g_signal_new (
+		"client-notify",
+		G_TYPE_FROM_CLASS (class),
+		/* same flags as GObject::notify */
+		G_SIGNAL_RUN_FIRST |
+		G_SIGNAL_NO_RECURSE |
+		G_SIGNAL_DETAILED |
+		G_SIGNAL_NO_HOOKS |
+		G_SIGNAL_ACTION,
+		G_STRUCT_OFFSET (EClientCacheClass, client_notify),
+		NULL, NULL, NULL,
+		G_TYPE_NONE, 2,
+		E_TYPE_CLIENT,
+		G_TYPE_PARAM);
 }
 
 static void
-e_client_cache_init (EClientCache *cache)
+e_client_cache_init (EClientCache *client_cache)
 {
 	GHashTable *client_ht;
 	gint ii;
@@ -719,12 +859,12 @@ e_client_cache_init (EClientCache *cache)
 		(GDestroyNotify) g_free,
 		(GDestroyNotify) g_hash_table_unref);
 
-	cache->priv = E_CLIENT_CACHE_GET_PRIVATE (cache);
+	client_cache->priv = E_CLIENT_CACHE_GET_PRIVATE (client_cache);
 
-	cache->priv->main_context = g_main_context_ref_thread_default ();
-	cache->priv->client_ht = client_ht;
+	client_cache->priv->main_context = g_main_context_ref_thread_default ();
+	client_cache->priv->client_ht = client_ht;
 
-	g_mutex_init (&cache->priv->client_ht_lock);
+	g_mutex_init (&client_cache->priv->client_ht_lock);
 
 	/* Pre-load the extension names that can be used to instantiate
 	 * EClients.  Then we can validate an extension name by testing
@@ -768,7 +908,7 @@ e_client_cache_new (ESourceRegistry *registry)
 
 /**
  * e_client_cache_ref_registry:
- * @cache: an #EClientCache
+ * @client_cache: an #EClientCache
  *
  * Returns the #ESourceRegistry passed to e_client_cache_new().
  *
@@ -778,16 +918,16 @@ e_client_cache_new (ESourceRegistry *registry)
  * Returns: an #ESourceRegistry
  **/
 ESourceRegistry *
-e_client_cache_ref_registry (EClientCache *cache)
+e_client_cache_ref_registry (EClientCache *client_cache)
 {
-	g_return_val_if_fail (E_IS_CLIENT_CACHE (cache), NULL);
+	g_return_val_if_fail (E_IS_CLIENT_CACHE (client_cache), NULL);
 
-	return g_object_ref (cache->priv->registry);
+	return g_object_ref (client_cache->priv->registry);
 }
 
 /**
  * e_client_cache_get_client_sync:
- * @cache: an #EClientCache
+ * @client_cache: an #EClientCache
  * @source: an #ESource
  * @extension_name: an extension name
  * @cancellable: optional #GCancellable object, or %NULL
@@ -826,7 +966,7 @@ e_client_cache_ref_registry (EClientCache *cache)
  * Returns: an #EClient, or %NULL
  **/
 EClient *
-e_client_cache_get_client_sync (EClientCache *cache,
+e_client_cache_get_client_sync (EClientCache *client_cache,
                                 ESource *source,
                                 const gchar *extension_name,
                                 GCancellable *cancellable,
@@ -836,19 +976,20 @@ e_client_cache_get_client_sync (EClientCache *cache,
 	GAsyncResult *result;
 	EClient *client;
 
-	g_return_val_if_fail (E_IS_CLIENT_CACHE (cache), NULL);
+	g_return_val_if_fail (E_IS_CLIENT_CACHE (client_cache), NULL);
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
 	g_return_val_if_fail (extension_name != NULL, NULL);
 
 	closure = e_async_closure_new ();
 
 	e_client_cache_get_client (
-		cache, source, extension_name, cancellable,
+		client_cache, source, extension_name,cancellable,
 		e_async_closure_callback, closure);
 
 	result = e_async_closure_wait (closure);
 
-	client = e_client_cache_get_client_finish (cache, result, error);
+	client = e_client_cache_get_client_finish (
+		client_cache, result, error);
 
 	e_async_closure_free (closure);
 
@@ -857,7 +998,7 @@ e_client_cache_get_client_sync (EClientCache *cache,
 
 /**
  * e_client_cache_get_client:
- * @cache: an #EClientCache
+ * @client_cache: an #EClientCache
  * @source: an #ESource
  * @extension_name: an extension name
  * @cancellable: optional #GCancellable object, or %NULL
@@ -895,7 +1036,7 @@ e_client_cache_get_client_sync (EClientCache *cache,
  * operation.
  **/
 void
-e_client_cache_get_client (EClientCache *cache,
+e_client_cache_get_client (EClientCache *client_cache,
                            ESource *source,
                            const gchar *extension_name,
                            GCancellable *cancellable,
@@ -907,17 +1048,17 @@ e_client_cache_get_client (EClientCache *cache,
 	EClient *client = NULL;
 	gboolean connect_in_progress = FALSE;
 
-	g_return_if_fail (E_IS_CLIENT_CACHE (cache));
+	g_return_if_fail (E_IS_CLIENT_CACHE (client_cache));
 	g_return_if_fail (E_IS_SOURCE (source));
 	g_return_if_fail (extension_name != NULL);
 
 	simple = g_simple_async_result_new (
-		G_OBJECT (cache), callback,
+		G_OBJECT (client_cache), callback,
 		user_data, e_client_cache_get_client);
 
 	g_simple_async_result_set_check_cancellable (simple, cancellable);
 
-	client_data = client_ht_lookup (cache, source, extension_name);
+	client_data = client_ht_lookup (client_cache, source, extension_name);
 
 	if (client_data == NULL) {
 		g_simple_async_result_set_error (
@@ -998,7 +1139,7 @@ exit:
 
 /**
  * e_client_cache_get_client_finish:
- * @cache: an #EClientCache
+ * @client_cache: an #EClientCache
  * @result: a #GAsyncResult
  * @error: return location for a #GError, or %NULL
  *
@@ -1011,7 +1152,7 @@ exit:
  * Returns: an #EClient, or %NULL
  **/
 EClient *
-e_client_cache_get_client_finish (EClientCache *cache,
+e_client_cache_get_client_finish (EClientCache *client_cache,
                                   GAsyncResult *result,
                                   GError **error)
 {
@@ -1020,7 +1161,7 @@ e_client_cache_get_client_finish (EClientCache *cache,
 
 	g_return_val_if_fail (
 		g_simple_async_result_is_valid (
-		result, G_OBJECT (cache),
+		result, G_OBJECT (client_cache),
 		e_client_cache_get_client), NULL);
 
 	simple = G_SIMPLE_ASYNC_RESULT (result);
@@ -1036,7 +1177,7 @@ e_client_cache_get_client_finish (EClientCache *cache,
 
 /**
  * e_client_cache_ref_cached_client:
- * @cache: an #EClientCache
+ * @client_cache: an #EClientCache
  * @source: an #ESource
  * @extension_name: an extension name
  *
@@ -1052,18 +1193,18 @@ e_client_cache_get_client_finish (EClientCache *cache,
  * Returns: an #EClient, or %NULL
  **/
 EClient *
-e_client_cache_ref_cached_client (EClientCache *cache,
+e_client_cache_ref_cached_client (EClientCache *client_cache,
                                   ESource *source,
                                   const gchar *extension_name)
 {
 	ClientData *client_data;
 	EClient *client = NULL;
 
-	g_return_val_if_fail (E_IS_CLIENT_CACHE (cache), NULL);
+	g_return_val_if_fail (E_IS_CLIENT_CACHE (client_cache), NULL);
 	g_return_val_if_fail (E_IS_SOURCE (source), NULL);
 	g_return_val_if_fail (extension_name != NULL, NULL);
 
-	client_data = client_ht_lookup (cache, source, extension_name);
+	client_data = client_ht_lookup (client_cache, source, extension_name);
 
 	if (client_data != NULL) {
 		g_mutex_lock (&client_data->lock);
@@ -1076,3 +1217,38 @@ e_client_cache_ref_cached_client (EClientCache *cache,
 
 	return client;
 }
+
+/**
+ * e_client_cache_is_backend_dead:
+ * @client_cache: an #EClientCache
+ * @source: an #ESource
+ * @extension_name: an extension name
+ *
+ * Returns %TRUE if an #EClient instance for @source and @extension_name
+ * was recently discarded after having emitted a #EClient::backend-died
+ * signal, and a replacement #EClient instance has not yet been created.
+ *
+ * Returns: whether the backend for @source and @extension_name died
+ **/
+gboolean
+e_client_cache_is_backend_dead (EClientCache *client_cache,
+                                ESource *source,
+                                const gchar *extension_name)
+{
+	ClientData *client_data;
+	gboolean dead_backend = FALSE;
+
+	g_return_val_if_fail (E_IS_CLIENT_CACHE (client_cache), FALSE);
+	g_return_val_if_fail (E_IS_SOURCE (source), FALSE);
+	g_return_val_if_fail (extension_name != NULL, FALSE);
+
+	client_data = client_ht_lookup (client_cache, source, extension_name);
+
+	if (client_data != NULL) {
+		dead_backend = client_data->dead_backend;
+		client_data_unref (client_data);
+	}
+
+	return dead_backend;
+}
+
