@@ -81,6 +81,8 @@
 #include <e-util/e-charset-combo-box.h>
 #include <e-util/e-charset.h>
 #include <e-util/e-client-cache.h>
+#include <e-util/e-client-combo-box.h>
+#include <e-util/e-client-selector.h>
 #include <e-util/e-config.h>
 #include <e-util/e-contact-store.h>
 #include <e-util/e-dateedit.h>
@@ -128,6 +130,7 @@
 #include <e-util/e-online-button.h>
 #include <e-util/e-paned.h>
 #include <e-util/e-passwords.h>
+#include <e-util/e-photo-cache.h>
 #include <e-util/e-picture-gallery.h>
 #include <e-util/e-plugin-ui.h>
 #include <e-util/e-plugin.h>
