@@ -47,7 +47,6 @@ void e_mail_formatter_internal_extensions_load (EMailExtensionRegistry *ereg);
 struct _EMailFormatterPrivate {
 	EMailImageLoadingPolicy image_loading_policy;
 
-	guint only_local_photos	: 1;
 	guint show_sender_photo	: 1;
 	guint show_real_date	: 1;
         guint animate_images    : 1;
@@ -75,7 +74,6 @@ enum {
 	PROP_IMAGE_LOADING_POLICY,
 	PROP_FORCE_IMAGE_LOADING,
 	PROP_MARK_CITATIONS,
-	PROP_ONLY_LOCAL_PHOTOS,
 	PROP_SHOW_SENDER_PHOTO,
 	PROP_SHOW_REAL_DATE,
         PROP_ANIMATE_IMAGES,
@@ -174,12 +172,6 @@ e_mail_formatter_set_property (GObject *object,
 				g_value_get_boolean (value));
 			return;
 
-		case PROP_ONLY_LOCAL_PHOTOS:
-			e_mail_formatter_set_only_local_photos (
-				E_MAIL_FORMATTER (object),
-				g_value_get_boolean (value));
-			return;
-
 		case PROP_SHOW_SENDER_PHOTO:
 			e_mail_formatter_set_show_sender_photo (
 				E_MAIL_FORMATTER (object),
@@ -282,13 +274,6 @@ e_mail_formatter_get_property (GObject *object,
 				E_MAIL_FORMATTER (object)));
 			return;
 
-		case PROP_ONLY_LOCAL_PHOTOS:
-			g_value_set_boolean (
-				value,
-				e_mail_formatter_get_only_local_photos (
-				E_MAIL_FORMATTER (object)));
-			return;
-
 		case PROP_SHOW_SENDER_PHOTO:
 			g_value_set_boolean (
 				value,
@@ -654,17 +639,6 @@ e_mail_formatter_class_init (EMailFormatterClass *class)
 			TRUE,
 			G_PARAM_READWRITE));
 
-	g_object_class_install_property (
-		object_class,
-		PROP_ONLY_LOCAL_PHOTOS,
-		g_param_spec_boolean (
-			"only-local-photos",
-			"Only Local Photos",
-			NULL,
-			TRUE,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT));
-
 	g_object_class_install_property (
 		object_class,
 		PROP_SHOW_SENDER_PHOTO,
@@ -1241,28 +1215,6 @@ e_mail_formatter_set_mark_citations (EMailFormatter *formatter,
 	g_object_notify (G_OBJECT (formatter), "mark-citations");
 }
 
-gboolean
-e_mail_formatter_get_only_local_photos (EMailFormatter *formatter)
-{
-	g_return_val_if_fail (E_IS_MAIL_FORMATTER (formatter), FALSE);
-
-	return formatter->priv->only_local_photos;
-}
-
-void
-e_mail_formatter_set_only_local_photos (EMailFormatter *formatter,
-                                        gboolean only_local_photos)
-{
-	g_return_if_fail (E_IS_MAIL_FORMATTER (formatter));
-
-	if (formatter->priv->only_local_photos == only_local_photos)
-		return;
-
-	formatter->priv->only_local_photos = only_local_photos;
-
-	g_object_notify (G_OBJECT (formatter), "only-local-photos");
-}
-
 gboolean
 e_mail_formatter_get_show_sender_photo (EMailFormatter *formatter)
 {
