@@ -33,14 +33,6 @@ gboolean	em_utils_folder_is_sent		(ESourceRegistry *registry,
 						 CamelFolder *folder);
 gboolean	em_utils_folder_is_outbox	(ESourceRegistry *registry,
 						 CamelFolder *folder);
-gboolean	em_utils_in_addressbook		(ESourceRegistry *registry,
-						 CamelInternetAddress *addr,
-						 gboolean local_only,
-						 GCancellable *cancellable);
-CamelMimePart *	em_utils_contact_photo		(ESourceRegistry *registry,
-						 CamelInternetAddress *addr,
-						 gboolean local,
-						 GCancellable *cancellable);
 ESource *	em_utils_guess_mail_account	(ESourceRegistry *registry,
 						 CamelMimeMessage *message,
 						 CamelFolder *folder,
@@ -62,10 +54,6 @@ ESource *	em_utils_guess_mail_identity_with_recipients
 ESource *	em_utils_ref_mail_identity_for_store
 						(ESourceRegistry *registry,
 						 CamelStore *store);
-void		emu_remove_from_mail_cache	(const GSList *addresses);
-void		emu_remove_from_mail_cache_1	(const gchar *address);
-void		emu_free_mail_cache		(GDestroyNotify done_cb,
-						 gpointer user_data);
 void		em_utils_uids_free		(GPtrArray *uids);
 gboolean	em_utils_is_local_delivery_mbox_file
 						(CamelURL *url);
