@@ -214,7 +214,8 @@ book_shell_view_client_connect_cb (GObject *source_object,
 	EAddressbookModel *model;
 	GError *error = NULL;
 
-	client = e_book_client_connect_finish (result, &error);
+	client = e_client_cache_get_client_finish (
+		E_CLIENT_CACHE (source_object), result, &error);
 
 	/* Sanity check. */
 	g_return_if_fail (
@@ -255,10 +256,13 @@ static void
 book_shell_view_activate_selected_source (EBookShellView *book_shell_view,
                                           ESourceSelector *selector)
 {
+	EShell *shell;
 	EShellView *shell_view;
+	EShellBackend *shell_backend;
 	EBookShellContent *book_shell_content;
 	EAddressbookView *view;
 	EAddressbookModel *model;
+	EClientCache *client_cache;
 	ESource *source;
 	GalViewInstance *view_instance;
 	GHashTable *hash_table;
@@ -267,6 +271,9 @@ book_shell_view_activate_selected_source (EBookShellView *book_shell_view,
 	gchar *view_id;
 
 	shell_view = E_SHELL_VIEW (book_shell_view);
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
+	shell = e_shell_backend_get_shell (shell_backend);
+	client_cache = e_shell_get_client_cache (shell);
 
 	book_shell_content = book_shell_view->priv->book_shell_content;
 	source = e_source_selector_ref_primary_selection (selector);
@@ -288,8 +295,10 @@ book_shell_view_activate_selected_source (EBookShellView *book_shell_view,
 
 		if (e_addressbook_model_get_client (model) == NULL)
 			/* XXX No way to cancel this? */
-			e_book_client_connect (
-				source, NULL,
+			e_client_cache_get_client (
+				client_cache, source,
+				E_SOURCE_EXTENSION_ADDRESS_BOOK,
+				NULL,
 				book_shell_view_client_connect_cb,
 				g_object_ref (view));
 
@@ -334,8 +343,10 @@ book_shell_view_activate_selected_source (EBookShellView *book_shell_view,
 		model = e_addressbook_view_get_model (view);
 
 		/* XXX No way to cancel this? */
-		e_book_client_connect (
-			source, NULL,
+		e_client_cache_get_client (
+			client_cache, source,
+			E_SOURCE_EXTENSION_ADDRESS_BOOK,
+			NULL,
 			book_shell_view_client_connect_cb,
 			g_object_ref (view));
 
@@ -416,6 +427,30 @@ book_shell_view_selector_popup_menu_cb (EShellView *shell_view)
 	return book_shell_view_show_popup_menu (NULL, shell_view);
 }
 
+static void
+book_shell_view_backend_error_cb (EClientCache *client_cache,
+                                  EClient *client,
+                                  EAlert *alert,
+                                  EBookShellView *book_shell_view)
+{
+	EBookShellContent *book_shell_content;
+	ESource *source;
+	const gchar *extension_name;
+
+	book_shell_content = book_shell_view->priv->book_shell_content;
+
+	source = e_client_get_source (client);
+	extension_name = E_SOURCE_EXTENSION_ADDRESS_BOOK;
+
+	/* Only submit alerts from address book backends. */
+	if (e_source_has_extension (source, extension_name)) {
+		EAlertSink *alert_sink;
+
+		alert_sink = E_ALERT_SINK (book_shell_content);
+		e_alert_sink_submit_alert (alert_sink, alert);
+	}
+}
+
 static void
 book_shell_view_source_removed_cb (ESourceRegistry *registry,
                                    ESource *source,
@@ -530,6 +565,7 @@ e_book_shell_view_private_constructed (EBookShellView *book_shell_view)
 	EShellSidebar *shell_sidebar;
 	EShellBackend *shell_backend;
 	ESourceSelector *selector;
+	gulong handler_id;
 
 	shell_view = E_SHELL_VIEW (book_shell_view);
 	shell_backend = e_shell_view_get_shell_backend (shell_view);
@@ -546,6 +582,10 @@ e_book_shell_view_private_constructed (EBookShellView *book_shell_view)
 	priv->book_shell_content = g_object_ref (shell_content);
 	priv->book_shell_sidebar = g_object_ref (shell_sidebar);
 
+	/* Keep our own reference to this so we can
+	 * disconnect our signal handler in dispose(). */
+	priv->client_cache = g_object_ref (e_shell_get_client_cache (shell));
+
 	/* Keep our own reference to this so we can
 	 * disconnect our signal handler in dispose(). */
 	priv->registry = g_object_ref (e_shell_get_registry (shell));
@@ -553,10 +593,17 @@ e_book_shell_view_private_constructed (EBookShellView *book_shell_view)
 	selector = e_book_shell_sidebar_get_selector (
 		E_BOOK_SHELL_SIDEBAR (shell_sidebar));
 
-	g_signal_connect (
+	handler_id = g_signal_connect (
+		priv->client_cache, "backend-error",
+		G_CALLBACK (book_shell_view_backend_error_cb),
+		book_shell_view);
+	priv->backend_error_handler_id = handler_id;
+
+	handler_id = g_signal_connect (
 		priv->registry, "source-removed",
 		G_CALLBACK (book_shell_view_source_removed_cb),
 		book_shell_view);
+	priv->source_removed_handler_id = handler_id;
 
 	g_signal_connect_object (
 		selector, "button-press-event",
@@ -587,18 +634,27 @@ e_book_shell_view_private_dispose (EBookShellView *book_shell_view)
 {
 	EBookShellViewPrivate *priv = book_shell_view->priv;
 
-	DISPOSE (priv->book_shell_backend);
-	DISPOSE (priv->book_shell_content);
-	DISPOSE (priv->book_shell_sidebar);
-
-	if (priv->registry != NULL) {
-		g_signal_handlers_disconnect_matched (
-			priv->registry, G_SIGNAL_MATCH_DATA,
-			0, 0, NULL, NULL, book_shell_view);
-		g_object_unref (priv->registry);
-		priv->registry = NULL;
+	if (priv->backend_error_handler_id > 0) {
+		g_signal_handler_disconnect (
+			priv->client_cache,
+			priv->backend_error_handler_id);
+		priv->backend_error_handler_id = 0;
 	}
 
+	if (priv->source_removed_handler_id > 0) {
+		g_signal_handler_disconnect (
+			priv->registry,
+			priv->source_removed_handler_id);
+		priv->source_removed_handler_id = 0;
+	}
+
+	g_clear_object (&priv->book_shell_backend);
+	g_clear_object (&priv->book_shell_content);
+	g_clear_object (&priv->book_shell_sidebar);
+
+	g_clear_object (&priv->client_cache);
+	g_clear_object (&priv->registry);
+
 	g_hash_table_remove_all (priv->uid_to_view);
 }
 
