@@ -57,12 +57,6 @@
 #define ACTION_GROUP(name) \
 	(E_SHELL_WINDOW_ACTION_GROUP_##name (shell_window))
 
-/* For use in dispose() methods. */
-#define DISPOSE(obj) \
-	G_STMT_START { \
-	if ((obj) != NULL) { g_object_unref (obj); (obj) = NULL; } \
-	} G_STMT_END
-
 /* ETable Specifications */
 #define ETSPEC_FILENAME		"e-addressbook-view.etspec"
 
@@ -90,7 +84,12 @@ struct _EBookShellViewPrivate {
 	EBookShellContent *book_shell_content;
 	EBookShellSidebar *book_shell_sidebar;
 
+	EClientCache *client_cache;
+	gulong backend_error_handler_id;
+
 	ESourceRegistry *registry;
+	gulong source_removed_handler_id;
+
 	GHashTable *uid_to_view;
 
 	gint preview_index;
