@@ -67,8 +67,7 @@ struct _ConnectClosure {
 	ECalShellSidebar *cal_shell_sidebar;
 
 	/* For error messages. */
-	gchar *source_display_name;
-	gchar *parent_display_name;
+	gchar *unique_display_name;
 };
 
 enum {
@@ -99,20 +98,15 @@ connect_closure_new (ECalShellSidebar *cal_shell_sidebar,
 	ConnectClosure *closure;
 	ESourceRegistry *registry;
 	ESourceSelector *selector;
-	ESource *parent;
-	const gchar *parent_uid;
 
 	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
 	registry = e_source_selector_get_registry (selector);
-	parent_uid = e_source_get_parent (source);
-	parent = e_source_registry_ref_source (registry, parent_uid);
 
 	closure = g_slice_new0 (ConnectClosure);
 	closure->cal_shell_sidebar = g_object_ref (cal_shell_sidebar);
-	closure->source_display_name = e_source_dup_display_name (source);
-	closure->parent_display_name = e_source_dup_display_name (parent);
-
-	g_object_unref (parent);
+	closure->unique_display_name =
+		e_source_registry_dup_unique_display_name (
+		registry, source, E_SOURCE_EXTENSION_CALENDAR);
 
 	return closure;
 }
@@ -122,8 +116,7 @@ connect_closure_free (ConnectClosure *closure)
 {
 	g_object_unref (closure->cal_shell_sidebar);
 
-	g_free (closure->source_display_name);
-	g_free (closure->parent_display_name);
+	g_free (closure->unique_display_name);
 
 	g_slice_free (ConnectClosure, closure);
 }
@@ -155,26 +148,9 @@ cal_shell_sidebar_emit_status_message (ECalShellSidebar *cal_shell_sidebar,
 	g_signal_emit (cal_shell_sidebar, signal_id, 0, status_message);
 }
 
-static EClientCache *
-cal_shell_sidebar_ref_client_cache (ECalShellSidebar *cal_shell_sidebar)
-{
-	EShell *shell;
-	EShellView *shell_view;
-	EShellBackend *shell_backend;
-	EShellSidebar *shell_sidebar;
-
-	shell_sidebar = E_SHELL_SIDEBAR (cal_shell_sidebar);
-	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
-	shell_backend = e_shell_view_get_shell_backend (shell_view);
-	shell = e_shell_backend_get_shell (shell_backend);
-
-	return g_object_ref (e_shell_get_client_cache (shell));
-}
-
 static void
 cal_shell_sidebar_handle_connect_error (ECalShellSidebar *cal_shell_sidebar,
-                                        const gchar *parent_display_name,
-                                        const gchar *source_display_name,
+                                        const gchar *unique_display_name,
                                         const GError *error)
 {
 	EShellView *shell_view;
@@ -201,15 +177,13 @@ cal_shell_sidebar_handle_connect_error (ECalShellSidebar *cal_shell_sidebar,
 		e_alert_submit (
 			E_ALERT_SINK (shell_content),
 			"calendar:prompt-no-contents-offline-calendar",
-			parent_display_name,
-			source_display_name,
+			unique_display_name,
 			NULL);
 	} else {
 		e_alert_submit (
 			E_ALERT_SINK (shell_content),
 			"calendar:failed-open-calendar",
-			parent_display_name,
-			source_display_name,
+			unique_display_name,
 			error->message,
 			NULL);
 	}
@@ -224,8 +198,8 @@ cal_shell_sidebar_client_connect_cb (GObject *source_object,
 	ConnectClosure *closure = user_data;
 	GError *error = NULL;
 
-	client = e_client_cache_get_client_finish (
-		E_CLIENT_CACHE (source_object), result, &error);
+	client = e_client_selector_get_client_finish (
+		E_CLIENT_SELECTOR (source_object), result, &error);
 
 	/* Sanity check. */
 	g_return_if_fail (
@@ -235,8 +209,7 @@ cal_shell_sidebar_client_connect_cb (GObject *source_object,
 	if (error != NULL) {
 		cal_shell_sidebar_handle_connect_error (
 			closure->cal_shell_sidebar,
-			closure->parent_display_name,
-			closure->source_display_name,
+			closure->unique_display_name,
 			error);
 		g_error_free (error);
 		goto exit;
@@ -263,8 +236,8 @@ cal_shell_sidebar_default_connect_cb (GObject *source_object,
 
 	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (closure->cal_shell_sidebar);
 
-	client = e_client_cache_get_client_finish (
-		E_CLIENT_CACHE (source_object), result, &error);
+	client = e_client_selector_get_client_finish (
+		E_CLIENT_SELECTOR (source_object), result, &error);
 
 	/* Sanity check. */
 	g_return_if_fail (
@@ -279,8 +252,7 @@ cal_shell_sidebar_default_connect_cb (GObject *source_object,
 	if (error != NULL) {
 		cal_shell_sidebar_handle_connect_error (
 			closure->cal_shell_sidebar,
-			closure->parent_display_name,
-			closure->source_display_name,
+			closure->unique_display_name,
 			error);
 		g_error_free (error);
 		goto exit;
@@ -310,10 +282,12 @@ cal_shell_sidebar_set_default (ECalShellSidebar *cal_shell_sidebar,
                                ESource *source)
 {
 	ECalShellSidebarPrivate *priv;
-	EClientCache *client_cache;
+	ESourceSelector *selector;
 
 	priv = cal_shell_sidebar->priv;
 
+	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
+
 	/* already loading that source as default source */
 	if (source == priv->connecting_default_source_instance)
 		return;
@@ -329,17 +303,11 @@ cal_shell_sidebar_set_default (ECalShellSidebar *cal_shell_sidebar,
 	priv->connecting_default_source_instance = source;
 	priv->connecting_default_client = g_cancellable_new ();
 
-	client_cache =
-		cal_shell_sidebar_ref_client_cache (cal_shell_sidebar);
-
-	e_client_cache_get_client (
-		client_cache, source,
-		E_SOURCE_EXTENSION_CALENDAR,
+	e_client_selector_get_client (
+		E_CLIENT_SELECTOR (selector), source,
 		priv->connecting_default_client,
 		cal_shell_sidebar_default_connect_cb,
 		connect_closure_new (cal_shell_sidebar, source));
-
-	g_object_unref (client_cache);
 }
 
 static void
@@ -533,7 +501,7 @@ cal_shell_sidebar_constructed (GObject *object)
 	EShellBackend *shell_backend;
 	EShellSidebar *shell_sidebar;
 	EShellSettings *shell_settings;
-	ESourceRegistry *registry;
+	EClientCache *client_cache;
 	ECalendarItem *calitem;
 	GtkWidget *container;
 	GtkWidget *widget;
@@ -589,8 +557,8 @@ cal_shell_sidebar_constructed (GObject *object)
 
 	container = widget;
 
-	registry = e_shell_get_registry (shell);
-	widget = e_calendar_selector_new (registry);
+	client_cache = e_shell_get_client_cache (shell);
+	widget = e_calendar_selector_new (client_cache);
 	e_source_selector_set_select_new (E_SOURCE_SELECTOR (widget), TRUE);
 	gtk_container_add (GTK_CONTAINER (container), widget);
 	a11y = gtk_widget_get_accessible (widget);
@@ -650,7 +618,6 @@ cal_shell_sidebar_check_state (EShellSidebar *shell_sidebar)
 	if (source != NULL) {
 		EClient *client;
 		ESource *collection;
-		EClientCache *client_cache;
 
 		has_primary_source = TRUE;
 		is_writable = e_source_get_writable (source);
@@ -665,11 +632,8 @@ cal_shell_sidebar_check_state (EShellSidebar *shell_sidebar)
 			g_object_unref (collection);
 		}
 
-		client_cache = cal_shell_sidebar_ref_client_cache (
-			E_CAL_SHELL_SIDEBAR (shell_sidebar));
-		client = e_client_cache_ref_cached_client (
-			client_cache, source, E_SOURCE_EXTENSION_CALENDAR);
-		g_object_unref (client_cache);
+		client = e_client_selector_ref_cached_client (
+			E_CLIENT_SELECTOR (selector), source);
 
 		if (client != NULL) {
 			refresh_supported =
@@ -869,7 +833,6 @@ e_cal_shell_sidebar_add_client (ECalShellSidebar *cal_shell_sidebar,
 {
 	ESource *source;
 	ESourceSelector *selector;
-	const gchar *message;
 
 	g_return_if_fail (E_IS_CAL_SHELL_SIDEBAR (cal_shell_sidebar));
 	g_return_if_fail (E_IS_CAL_CLIENT (client));
@@ -879,61 +842,56 @@ e_cal_shell_sidebar_add_client (ECalShellSidebar *cal_shell_sidebar,
 	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
 	e_source_selector_select_source (selector, source);
 
-	message = _("Loading calendars");
-	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, message);
 	cal_shell_sidebar_emit_client_added (cal_shell_sidebar, client);
-	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, NULL);
 }
 
 void
 e_cal_shell_sidebar_add_source (ECalShellSidebar *cal_shell_sidebar,
                                 ESource *source)
 {
+	ESourceRegistry *registry;
 	ESourceSelector *selector;
-	EClientCache *client_cache;
-	const gchar *display_name;
+	gchar *display_name;
 	gchar *message;
 
 	g_return_if_fail (E_IS_CAL_SHELL_SIDEBAR (cal_shell_sidebar));
 	g_return_if_fail (E_IS_SOURCE (source));
 
 	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
+	registry = e_source_selector_get_registry (selector);
 
 	e_source_selector_select_source (selector, source);
 
-	display_name = e_source_get_display_name (source);
+	display_name = e_source_registry_dup_unique_display_name (
+		registry, source, E_SOURCE_EXTENSION_CALENDAR);
+
 	message = g_strdup_printf (_("Opening calendar '%s'"), display_name);
 	cal_shell_sidebar_emit_status_message (cal_shell_sidebar, message);
 	g_free (message);
 
-	client_cache =
-		cal_shell_sidebar_ref_client_cache (cal_shell_sidebar);
+	g_free (display_name);
 
-	e_client_cache_get_client (
-		client_cache, source,
-		E_SOURCE_EXTENSION_CALENDAR,
+	e_client_selector_get_client (
+		E_CLIENT_SELECTOR (selector), source,
 		cal_shell_sidebar->priv->loading_clients,
 		cal_shell_sidebar_client_connect_cb,
 		connect_closure_new (cal_shell_sidebar, source));
-
-	g_object_unref (client_cache);
 }
 
 void
 e_cal_shell_sidebar_remove_source (ECalShellSidebar *cal_shell_sidebar,
                                    ESource *source)
 {
-	EClientCache *client_cache;
+	ESourceSelector *selector;
 	EClient *client;
 
 	g_return_if_fail (E_IS_CAL_SHELL_SIDEBAR (cal_shell_sidebar));
 	g_return_if_fail (E_IS_SOURCE (source));
 
-	client_cache =
-		cal_shell_sidebar_ref_client_cache (cal_shell_sidebar);
-	client = e_client_cache_ref_cached_client (
-		client_cache, source, E_SOURCE_EXTENSION_CALENDAR);
-	g_object_unref (client_cache);
+	selector = e_cal_shell_sidebar_get_selector (cal_shell_sidebar);
+
+	client = e_client_selector_ref_cached_client (
+		E_CLIENT_SELECTOR (selector), source);
 
 	if (client != NULL) {
 		cal_shell_sidebar_emit_client_removed (
