@@ -54,12 +54,6 @@
 #define ACTION_GROUP(name) \
 	(E_SHELL_WINDOW_ACTION_GROUP_##name (shell_window))
 
-/* For use in dispose() methods. */
-#define DISPOSE(obj) \
-	G_STMT_START { \
-	if ((obj) != NULL) { g_object_unref (obj); (obj) = NULL; } \
-	} G_STMT_END
-
 /* ETable Specifications */
 #define ETSPEC_FILENAME		"e-calendar-table.etspec"
 
@@ -92,6 +86,9 @@ struct _ETaskShellViewPrivate {
 	ETaskShellContent *task_shell_content;
 	ETaskShellSidebar *task_shell_sidebar;
 
+	EClientCache *client_cache;
+	gulong backend_error_handler_id;
+
 	EActivity *activity;
 	guint update_timeout;
 	guint update_completed_timeout;
@@ -126,8 +123,6 @@ void		e_task_shell_view_update_sidebar
 					(ETaskShellView *task_shell_view);
 void		e_task_shell_view_update_search_filter
 					(ETaskShellView *task_shell_view);
-void		e_task_shell_view_update_timezone
-					(ETaskShellView *task_shell_view);
 
 G_END_DECLS
 
